@@ -32,6 +32,7 @@
 #include <unistd.h>
 
 #include <gst/check/gstcheck.h>
+#include <gst/check/gstharness.h>
 
 /* For ease of programming we use globals to keep refs for our floating
  * src and sink pads we create; otherwise we always have to do get_pad,
@@ -465,6 +466,7 @@ GST_START_TEST (test_backward_playback)
   /* clean up */
   gst_pad_remove_probe (pad, pad_probe);
   gst_object_unref (pad);
+  gst_object_unref (src);
   g_main_loop_unref (loop);
   g_source_remove (bus_watch);
   gst_object_unref (bin);
@@ -472,6 +474,129 @@ GST_START_TEST (test_backward_playback)
 
 GST_END_TEST;
 
+GST_START_TEST (test_duration_query)
+{
+  GstElement *bin;
+  GError *error = NULL;
+  GstStateChangeReturn ret;
+  gboolean queryret;
+  gint64 duration = -1;
+
+  bin =
+      gst_parse_launch ("videotestsrc ! fakesink name=sink sync=true", &error);
+  ret = gst_element_set_state (bin, GST_STATE_PAUSED);
+  if (ret == GST_STATE_CHANGE_ASYNC) {
+    ret = gst_element_get_state (bin, NULL, NULL, GST_CLOCK_TIME_NONE);
+    fail_if (ret != GST_STATE_CHANGE_SUCCESS, "Could not start test pipeline");
+  }
+  queryret = gst_element_query_duration (bin, GST_FORMAT_TIME, &duration);
+  /* should have unknown duration */
+  if (queryret && duration != -1) {
+    fail ("Should return false on duration query");
+  }
+  gst_element_set_state (bin, GST_STATE_NULL);
+  gst_object_unref (bin);
+
+  bin = gst_parse_launch ("videotestsrc num-buffers=100 ! capsfilter "
+      "caps=\"video/x-raw,framerate=(fraction)10/1\" ! "
+      "fakesink name=sink sync=true", &error);
+  ret = gst_element_set_state (bin, GST_STATE_PAUSED);
+  if (ret == GST_STATE_CHANGE_ASYNC) {
+    ret = gst_element_get_state (bin, NULL, NULL, GST_CLOCK_TIME_NONE);
+    fail_if (ret != GST_STATE_CHANGE_SUCCESS, "Could not start test pipeline");
+  }
+  queryret = gst_element_query_duration (bin, GST_FORMAT_TIME, &duration);
+  fail_unless (queryret, "Duration should be returned");
+  fail_unless (duration == GST_SECOND * 10, "Expected duration didn't match");
+
+  /* reverse playback should have no impact on duration */
+  gst_element_seek (bin, -1.0, GST_FORMAT_TIME,
+      GST_SEEK_FLAG_ACCURATE | GST_SEEK_FLAG_FLUSH, GST_SEEK_TYPE_SET,
+      0, GST_SEEK_TYPE_SET, 1 * GST_SECOND);
+  queryret = gst_element_query_duration (bin, GST_FORMAT_TIME, &duration);
+  fail_unless (queryret, "Duration should be returned");
+  fail_unless (duration == GST_SECOND * 10, "Expected duration didn't match");
+
+  gst_element_set_state (bin, GST_STATE_NULL);
+  gst_object_unref (bin);
+}
+
+GST_END_TEST;
+
+static gchar *
+get_buffer_checksum (GstBuffer * buf)
+{
+  GstMapInfo map = GST_MAP_INFO_INIT;
+  GChecksum *md5 = g_checksum_new (G_CHECKSUM_MD5);
+  gchar *ret;
+
+  gst_buffer_map (buf, &map, GST_MAP_READ);
+  g_checksum_update (md5, map.data, map.size);
+  gst_buffer_unmap (buf, &map);
+
+  ret = g_strdup (g_checksum_get_string (md5));
+  g_checksum_free (md5);
+
+  return ret;
+}
+
+GST_START_TEST (test_patterns_are_deterministic)
+{
+  GType type;
+  GEnumClass *enum_class;
+  gint num_patterns;
+  GstHarness *h[2];
+  const gint num_instances = G_N_ELEMENTS (h);
+  const gint num_frames = 2;
+  gint pattern, i, frame;
+
+  /* Create an element to register types used below */
+  gst_object_unref (gst_element_factory_make ("videotestsrc", NULL));
+
+  /* Find number of patterns to check */
+  type = g_type_from_name ("GstVideoTestSrcPattern");
+  fail_unless (type != 0);
+  enum_class = g_type_class_ref (type);
+  num_patterns = enum_class->n_values;
+  fail_unless (num_patterns > 0);
+  g_type_class_unref (enum_class);
+
+  /* For each pattern, make sure that all instances produce identical
+   * frames */
+  for (pattern = 0; pattern < num_patterns; pattern++) {
+
+    for (i = 0; i < G_N_ELEMENTS (h); i++) {
+      h[i] = gst_harness_new ("videotestsrc");
+      g_object_set (h[i]->element, "pattern", pattern, NULL);
+      gst_harness_set_blocking_push_mode (h[i]);
+      gst_harness_play (h[i]);
+    }
+
+    for (frame = 0; frame < num_frames; frame++) {
+      gchar *ref_checksum = NULL;
+
+      for (i = 0; i < num_instances; i++) {
+        GstBuffer *buffer = gst_harness_pull (h[i]);
+        gchar *checksum = get_buffer_checksum (buffer);
+
+        if (i == 0)
+          ref_checksum = g_strdup (checksum);
+
+        fail_unless_equals_string (ref_checksum, checksum);
+
+        g_free (checksum);
+        gst_buffer_unref (buffer);
+      }
+      g_free (ref_checksum);
+    }
+    for (i = 0; i < G_N_ELEMENTS (h); i++)
+      gst_harness_teardown (h[i]);
+  }
+}
+
+GST_END_TEST;
+
+
 
 /* FIXME: add tests for YUV formats */
 
@@ -493,6 +618,8 @@ videotestsrc_suite (void)
   tcase_add_test (tc_chain, test_all_patterns);
   tcase_add_test (tc_chain, test_rgb_formats);
   tcase_add_test (tc_chain, test_backward_playback);
+  tcase_add_test (tc_chain, test_duration_query);
+  tcase_add_test (tc_chain, test_patterns_are_deterministic);
 
   return s;
 }
